if "$EUROMOD_PATH" == "" {
	global EUROMOD_PATH = "C:/Program Files/EUROMOD/Executable"
}
adopath + "$EUROMOD_PATH"
capture program drop EM_StataPlugin
capture program EM_StataPlugin, plugin using ("$EUROMOD_PATH/StataPlugin.plugin")
capture program drop euromod_getdata
program define euromod_getdata, rclass
	set type double
	syntax , OUTputdataset(string) [replace PREfix(string)]
	capture confirm variable idperson
	if (_rc == 0) {
		qui capture plugin call EM_StataPlugin idperson if __simulated__, "checkConcatenation" "`outputdataset'"
	} 
	//Check if data needs to be replaced before throwing an error
	if (_rc != 0) {
	    if ("`replace'" != "replace") {
	    qui cd "`wd'"
		noi di in r "Output dataset cannot be concatenated."
		noi di in r "Consider replacing existing dataset with current one using replace option."
		error -1
		exit
		}
	}
	if ("`replace'" == "replace") {
		qui ds, has(char inputvar)
		local previous_input = "`r(varlist)'"
		plugin call EM_StataPlugin, "setNobs" "`outputdataset'"
		clear
		di "nobs: `nObs'"
		insobs `nObs'
		gen __simulated__ = 1
	}
	
	qui plugin call EM_StataPlugin if __simulated__ , "setOutputVarsMacro" "`outputdataset'"
	local output_vars_stata ""
	foreach var of global vars_EM {
		//ensure unique varname of maximum length of 32
		local candidate = strtoname("`prefix'`var'")
		capture confirm variable `candidate'
		if _rc == 0 {
			// if exists already check first length, if necessary use substring
			local len_candidate = ustrlen("`candidate'")
			if `len_candidate' >= 30 {
				local candidate = substr("`candidate'",1,29)
			}
			//add a counter which you increase until variable name is for sure unique
			local counter = 0
			while _rc == 0 {
				local counter = `counter' + 1
				capture confirm variable `candidate'`counter'
			}
			local varname = "`candidate'`counter'"
		}
		else
		{
			local varname = "`candidate'"
		}
		capture gen `varname' = .
		char `varname'[simulated] "yes"
		if "`replace'" == "replace" {
			if  `: list varname in previous_input' {
				char `varname'[inputvar] "yes"
			}
		}
		//set variable name of euromod as label. Add optional prefix between parenthesises
		if "`prefix'" == "" {
			label variable `varname' "`var'"
		}
		else {
			label variable `varname' "`var' (`prefix')"
		}
		
		
		local output_vars_stata "`output_vars_stata' `varname'"
	}
	qui plugin call EM_StataPlugin `output_vars_stata' if __simulated__, "storeData" "`outputdataset'"
	// Setting return List Macros
	qui plugin call EM_StataPlugin, "setReturnList"
	foreach local_connector in `return_list_locals_connector' {
		return local `local_connector' = "`rlm`local_connector''"
	}
	
end